@@ -166,7 +166,7 @@ use DBI          ();
 
 use vars qw{$VERSION $errstr $MYSQL_SEQUENCE_TABLE};
 BEGIN {
-	$VERSION              = '1.02';
+	$VERSION              = '1.04';
 
 	# Class-level error string
 	$errstr               = '';
@@ -697,7 +697,7 @@ This would be a good thing. It would make things MUCH faster.
 
 =head1 AUTHORS
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 Patches are welcome
 
